mangadap.datacube package
=========================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.datacube.datacube
   mangadap.datacube.manga

Module contents
---------------

.. automodule:: mangadap.datacube
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
